Ubik is a lightweight, elegant, no-external web service linked and easy to use package manager. Inspired by the elegant Homebrew for OSX. 
It contain full toolchain for package creation and repository management.

Written in Python.

Features
--------

-  Install/Remove/Upgrade/Reinstall
-  Deps resolver for installation
-  Cache
-  Md5 checker
-  Package control file are Python objects
-  Full Python

Installation
------------

::

    pip install ubik


Tests
-----

Take a look at `tests <https://github.com/toxinu/ubik/tree/master/tests>`_ page.  
You can run tests with ``tests/run_tests.sh`` script.

Thanks
------

Thanks to `Requests`_, `Docopt`_ and `ProgressBar`_ to be awesome tools.

For information:

    Canopsis is an hypervisor, built on top of all open source monitoring solutions to agregate, correlate and ponderate events flowing from them.

License
-------

License is `AGPL3`_, it fully compatible with ``Canopsis``. See
`LICENSE`_.

.. _Canopsis: https://github.com/capensis/canopsis
.. _Ubik toolbelt: https://github.com/toxinu/ubik/blob/0.2/docs/TOOLBELT.rst
.. _Requests: https://github.com/kennethreitz/requests
.. _Docopt: https://github.com/docopt/docopt
.. _ProgressBar: http://code.google.com/p/python-progressbar/
.. _AGPL3: http://www.gnu.org/licenses/agpl.html
.. _LICENSE: https://raw.github.com/toxinu/ubik/master/LICENSE
